pub struct ParserRegistry { /* private fields */ }Expand description
Registry of language parsers with extension-based dispatch.
Implementations
Sourceimpl ParserRegistry
impl ParserRegistry
Sourcepub fn parser_for_file(&self, path: &Path) -> Option<&dyn LanguageParser>
pub fn parser_for_file(&self, path: &Path) -> Option<&dyn LanguageParser>
Get the parser for a file based on its extension.
Sourcepub fn parser_for_language(&self, lang: Language) -> Option<&dyn LanguageParser>
pub fn parser_for_language(&self, lang: Language) -> Option<&dyn LanguageParser>
Get the parser for a specific Language enum value.
Sourcepub fn supported_extensions(&self) -> Vec<&str>
pub fn supported_extensions(&self) -> Vec<&str>
List all supported file extensions.